@@ -26,8 +26,9 @@ int main()
 {
   using namespace __gnu_test;
 
-  // cplus-dem FAIL
-  verify_demangle("_Z1fPFPA1_ivE", "f(int (*(*)()) [1])");
+  // Equivalent, but formatting difference in void argument.
+  //  verify_demangle("_Z1fM1AFivEPS0_", "f(int (A::*)(void), int (*)(void))");
+  verify_demangle("_Z1fM1AFivEPS0_", "f(int (A::*)(), int (*)())");
 
   return 0;
 }
